CCL: /home/chisarie/Documents/lsst_ccl/CCL/src/ccl_utils.c File Reference

CCL

Functions
ccl_utils.c File Reference
`#include "ccl_utils.h"`
`#include <math.h>`
`#include <stdio.h>`
`#include <stdlib.h>`
`#include "ccl_params.h"`

## Functions
double * | ccl_linear_spacing (double xmin, double xmax, int N)
double * | ccl_log_spacing (double xmin, double xmax, int N)

## Function Documentation

## ◆ ccl_linear_spacing()

double* ccl_linear_spacing | ( | double | xmin,
|  | double | xmax,
|  | int | N
| ) |  |

Compute bin edges of N-1 linearly spaced bins on the interval [xmin,xmax]

Parameters

  xmin | minimum value of spacing
  xmax | maximum value of spacing
  N | number of bins plus one (number of bin edges)

Returns
  x, bin edges in range [xmin, xmax]

## ◆ ccl_log_spacing()

double* ccl_log_spacing | ( | double | xmin,
|  | double | xmax,
|  | int | N
| ) |  |

Compute bin edges of N-1 logarithmically spaced bins on the interval [xmin,xmax]

Parameters

  xmin | minimum value of spacing
  xmax | maximum value of spacing
  N | number of bins plus one (number of bin edges)

Returns
  x, bin edges in range [xmin, xmax]